@@ -3,6 +3,7 @@ import os
 import platform
 import subprocess
 import time
+import re
 
 from botocore.utils import parse_timestamp
 
@@ -25,6 +26,7 @@ class TestCodeArtifactLogin(unittest.TestCase):
         self.domain = 'domain'
         self.domain_owner = 'domain-owner'
         self.repository = 'repository'
+        self.endpoint_type = 'ipv4'
         self.auth_token = 'auth-token'
         self.namespace = 'namespace'
         self.nuget_index_url_fmt = '{endpoint}v3/index.json'
@@ -40,7 +42,15 @@ class TestCodeArtifactLogin(unittest.TestCase):
         self.pypi_rc_path_mock = self.pypi_rc_path_patch.start()
         self.pypi_rc_path_mock.return_value = self.test_pypi_rc_path
 
-        self.subprocess_patch = mock.patch('subprocess.check_call')
+        self.test_netrc_path = self.file_creator.full_path('.netrc')
+        self.get_netrc_path_patch = mock.patch(
+            'awscli.customizations.codeartifact.login.SwiftLogin'
+            '.get_netrc_path'
+        )
+        self.get_netrc_mock = self.get_netrc_path_patch.start()
+        self.get_netrc_mock.return_value = self.test_netrc_path
+
+        self.subprocess_patch = mock.patch('subprocess.run')
         self.subprocess_mock = self.subprocess_patch.start()
         self.subprocess_check_output_patch = mock.patch(
             'subprocess.check_output'
@@ -51,11 +61,15 @@ class TestCodeArtifactLogin(unittest.TestCase):
 
     def tearDown(self):
         self.pypi_rc_path_patch.stop()
+        self.subprocess_check_output_patch.stop()
+        self.get_netrc_path_patch.stop()
         self.subprocess_patch.stop()
         self.file_creator.remove_all()
 
     def _setup_cmd(self, tool,
-                   include_domain_owner=False, dry_run=False,
+                   include_domain_owner=False,
+                   dry_run=False,
+                   include_endpoint_type=False,
                    include_duration_seconds=False,
                    include_namespace=False):
         package_format = CodeArtifactLogin.TOOL_MAP[tool]['package_format']
@@ -77,6 +91,9 @@ class TestCodeArtifactLogin(unittest.TestCase):
         if include_domain_owner:
             cmdline.extend(['--domain-owner', self.domain_owner])
 
+        if include_endpoint_type:
+            cmdline.extend(['--endpoint-type', self.endpoint_type])
+
         if dry_run:
             cmdline.append('--dry-run')
 
@@ -106,6 +123,24 @@ class TestCodeArtifactLogin(unittest.TestCase):
 
         return cmdline
 
+    def _get_swift_commands(self, scope=None, token=None):
+        commands = []
+        set_registry_command = [
+            'swift', 'package-registry', 'set', self.endpoint
+        ]
+        if scope is not None:
+            set_registry_command.extend(['--scope', scope])
+        commands.append(set_registry_command)
+
+        login_registry_command = [
+            'swift', 'package-registry', 'login', f'{self.endpoint}login'
+        ]
+        if token is not None:
+            login_registry_command.extend(['--token', token])
+        commands.append(login_registry_command)
+
+        return commands
+
     def _get_nuget_commands(self):
         nuget_index_url = self.nuget_index_url_fmt.format(
             endpoint=self.endpoint
@@ -235,7 +270,8 @@ password: {auth_token}'''
 
     def _assert_operations_called(
         self, package_format, result,
-        include_domain_owner=False, include_duration_seconds=False
+        include_domain_owner=False, include_duration_seconds=False,
+        include_endpoint_type=False
     ):
 
         get_auth_token_kwargs = {
@@ -251,6 +287,9 @@ password: {auth_token}'''
             get_auth_token_kwargs['domainOwner'] = self.domain_owner
             get_repo_endpoint_kwargs['domainOwner'] = self.domain_owner
 
+        if include_endpoint_type:
+            get_repo_endpoint_kwargs['endpointType'] = self.endpoint_type
+
         if include_duration_seconds:
             get_auth_token_kwargs['durationSeconds'] = self.duration
 
@@ -274,8 +313,8 @@ password: {auth_token}'''
         expected_calls = [
             mock.call(
                 command,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
+                capture_output=True,
+                check=True
             ) for command in commands
         ]
         self.subprocess_mock.assert_has_calls(
@@ -330,13 +369,211 @@ password: {auth_token}'''
             self.assertIn('password', pypi_rc.options(server))
             self.assertEqual(pypi_rc.get(server, 'password'), password)
 
+    def _assert_netrc_has_expected_content(self):
+        with open(self.test_netrc_path, 'r') as f:
+            actual_contents = f.read()
+
+        hostname = urlparse.urlparse(self.endpoint).hostname
+        expected_contents = f'machine {hostname} login token password {self.auth_token}\n'
+        self.assertEqual(expected_contents, actual_contents)
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_without_domain_owner_macos(self):
+        cmdline = self._setup_cmd(tool='swift')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(token=self.auth_token)
+        )
+        self.assertFalse(os.path.exists(self.test_netrc_path))
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_without_domain_owner_non_macos(self):
+        cmdline = self._setup_cmd(tool='swift')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands()
+        )
+        self._assert_netrc_has_expected_content()
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_without_domain_owner_dry_run(self):
+        cmdline = self._setup_cmd(tool='swift', dry_run=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_dry_run_execution(self._get_swift_commands(), result.stdout)
+        self.assertFalse(os.path.exists(self.test_netrc_path))
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_domain_owner_macos(self):
+        cmdline = self._setup_cmd(tool='swift', include_domain_owner=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result,
+            include_domain_owner=True, include_duration_seconds=False
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(token=self.auth_token)
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_with_domain_owner_non_macos(self):
+        cmdline = self._setup_cmd(tool='swift', include_domain_owner=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result,
+            include_domain_owner=True, include_duration_seconds=False
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands()
+        )
+        self._assert_netrc_has_expected_content()
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_domain_owner_duration_macos(self):
+        cmdline = self._setup_cmd(tool='swift', include_domain_owner=True,
+                                  include_duration_seconds=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result,
+            include_domain_owner=True, include_duration_seconds=True
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(token=self.auth_token)
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_with_domain_owner_duration_non_macos(self):
+        cmdline = self._setup_cmd(tool='swift', include_domain_owner=True,
+                                  include_duration_seconds=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result,
+            include_domain_owner=True, include_duration_seconds=True
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands()
+        )
+        self._assert_netrc_has_expected_content()
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_with_domain_owner_dry_run(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_domain_owner=True, dry_run=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result, include_domain_owner=True
+        )
+        self._assert_dry_run_execution(
+            self._get_swift_commands(), result.stdout
+        )
+        self.assertFalse(os.path.exists(self.test_netrc_path))
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_domain_owner_duration_dry_run(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_domain_owner=True,
+            include_duration_seconds=True, dry_run=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='swift', result=result, include_domain_owner=True,
+            include_duration_seconds=True
+        )
+        self._assert_dry_run_execution(
+            self._get_swift_commands(token=self.auth_token), result.stdout
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_namespace_macos(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_namespace=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(scope=self.namespace, token=self.auth_token)
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_with_namespace_non_macos(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_namespace=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(scope=self.namespace)
+        )
+        self._assert_netrc_has_expected_content()
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_namespace_dry_run(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_namespace=True, dry_run=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result)
+        self._assert_dry_run_execution(
+            self._get_swift_commands(scope=self.namespace),result.stdout)
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', False)
+    def test_swift_login_with_namespace_with_endpoint_type(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_namespace=True, include_endpoint_type=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result, include_endpoint_type=True)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(scope=self.namespace)
+        )
+        self._assert_netrc_has_expected_content()
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_macos', True)
+    def test_swift_login_with_domain_owner_with_endpoint_type(self):
+        cmdline = self._setup_cmd(
+            tool='swift', include_domain_owner=True, include_endpoint_type=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='swift', result=result, include_endpoint_type=True,
+                                       include_domain_owner=True)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
+            self._get_swift_commands(token=self.auth_token)
+        )
+
     def test_nuget_login_without_domain_owner_without_duration_seconds(self):
         cmdline = self._setup_cmd(tool='nuget')
         result = self.cli_runner.run(cmdline)
         self.assertEqual(result.rc, 0)
         self._assert_operations_called(package_format='nuget', result=result)
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_nuget_commands()
         )
 
@@ -350,7 +587,7 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_nuget_commands()
         )
 
@@ -364,7 +601,7 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_nuget_commands()
         )
 
@@ -383,7 +620,28 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
+            self._get_nuget_commands()
+        )
+
+    def test_nuget_login_with_domain_owner_duration_endpoint_type(self):
+        cmdline = self._setup_cmd(
+            tool='nuget',
+            include_domain_owner=True,
+            include_duration_seconds=True,
+            include_endpoint_type=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='nuget',
+            include_domain_owner=True,
+            include_duration_seconds=True,
+            include_endpoint_type=True,
+            result=result
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
             self._get_nuget_commands()
         )
 
@@ -447,6 +705,26 @@ password: {auth_token}'''
             result.stdout
         )
 
+    def test_nuget_login_with_domain_owner_duration_seconds_with_endpoint_type_dryrun(self):
+        cmdline = self._setup_cmd(
+            tool='nuget', include_domain_owner=True,
+            include_duration_seconds=True,
+            dry_run=True, include_endpoint_type=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='nuget',
+            include_domain_owner=True,
+            include_duration_seconds=True,
+            include_endpoint_type=True,
+            result=result
+        )
+        self._assert_dry_run_execution(
+            self._get_nuget_commands(),
+            result.stdout
+        )
+
     @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
     def test_dotnet_login_without_domain_owner_without_duration_seconds(self):
         cmdline = self._setup_cmd(tool='dotnet')
@@ -454,7 +732,18 @@ password: {auth_token}'''
         self.assertEqual(result.rc, 0)
         self._assert_operations_called(package_format='nuget', result=result)
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
+            self._get_dotnet_commands()
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
+    def test_dotnet_login_without_domain_owner_without_duration_seconds_with_endpoint_type(self):
+        cmdline = self._setup_cmd(tool='dotnet', include_endpoint_type=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='nuget', result=result, include_endpoint_type=True)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(
             self._get_dotnet_commands()
         )
 
@@ -469,7 +758,7 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_dotnet_commands()
         )
 
@@ -484,7 +773,7 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_dotnet_commands()
         )
 
@@ -504,7 +793,7 @@ password: {auth_token}'''
             result=result
         )
         self._assert_expiration_printed_to_stdout(result.stdout)
-        self._assert_subprocess_check_output_execution(
+        self._assert_subprocess_execution(
             self._get_dotnet_commands()
         )
 
@@ -572,6 +861,49 @@ password: {auth_token}'''
             result.stdout
         )
 
+    _NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT = b"""\
+Welcome to dotnet 2.0!
+
+Registered Sources:
+  1. Source Name 1 [Enabled]
+     https://source1.com/index.json
+  2. ati-nugetserver [Disabled]
+     http://atinugetserver-env.elasticbeanstalk.com/nuget
+warn : You are running the 'list source' operation with an 'HTTP' source,
+'ati-nugetserver' [http://atinugetserver-env..elasticbeanstalk.com/nuget]'.
+Non-HTTPS access will be removed in a future version. Consider migrating
+to an 'HTTPS' source."""
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
+    def test_dotnet_login_sources_listed_with_extra_non_list_text(self):
+
+        self.subprocess_check_output_patch.return_value = \
+            self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+
+        cmdline = self._setup_cmd(tool='dotnet')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='nuget', result=result)
+        commands = [[
+            'dotnet', 'nuget', 'list', 'source', '--format', 'detailed'
+        ]]
+        self._assert_subprocess_check_output_execution(commands)
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
+    def test_dotnet_login_sources_listed_with_extra_non_list_text_with_endpoint_type(self):
+
+        self.subprocess_check_output_patch.return_value = \
+            self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+
+        cmdline = self._setup_cmd(tool='dotnet', include_endpoint_type=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='nuget', result=result, include_endpoint_type=True)
+        commands = [[
+            'dotnet', 'nuget', 'list', 'source', '--format', 'detailed'
+        ]]
+        self._assert_subprocess_check_output_execution(commands)
+
     def test_npm_login_without_domain_owner(self):
         cmdline = self._setup_cmd(tool='npm')
         result = self.cli_runner.run(cmdline)
@@ -595,7 +927,7 @@ password: {auth_token}'''
         exit code. This is to make sure that login ignores that error and all
         other commands executes successfully.
         """
-        def side_effect(command, stdout, stderr):
+        def side_effect(command, capture_output, check):
             if any('always-auth' in arg for arg in command):
                 raise subprocess.CalledProcessError(
                     returncode=1,
@@ -622,6 +954,18 @@ password: {auth_token}'''
         self._assert_expiration_printed_to_stdout(result.stdout)
         self._assert_subprocess_execution(self._get_npm_commands())
 
+    def test_npm_login_with_domain_owner_endpoint_type(self):
+        cmdline = self._setup_cmd(tool='npm', include_domain_owner=True, include_endpoint_type=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='npm', result=result,
+            include_domain_owner=True, include_duration_seconds=False,
+            include_endpoint_type=True
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(self._get_npm_commands())
+
     def test_npm_login_with_domain_owner_duration(self):
         cmdline = self._setup_cmd(tool='npm', include_domain_owner=True,
                                   include_duration_seconds=True)
@@ -669,6 +1013,18 @@ password: {auth_token}'''
             result.stdout
         )
 
+    def test_npm_login_with_namespace_endpoint_type_dry_run(self):
+        cmdline = self._setup_cmd(
+            tool='npm', include_namespace=True, dry_run=True, include_endpoint_type=True
+        )
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='npm', result=result, include_endpoint_type=True)
+        self._assert_dry_run_execution(
+            self._get_npm_commands(scope='@{}'.format(self.namespace)),
+            result.stdout
+        )
+
     def test_pip_login_without_domain_owner(self):
         cmdline = self._setup_cmd(tool='pip')
         result = self.cli_runner.run(cmdline)
@@ -706,6 +1062,18 @@ password: {auth_token}'''
         self._assert_expiration_printed_to_stdout(result.stdout)
         self._assert_subprocess_execution(self._get_pip_commands())
 
+    def test_pip_login_with_domain_owner_duration_endpoint_type(self):
+        cmdline = self._setup_cmd(tool='pip', include_domain_owner=True,
+                                  include_duration_seconds=True, include_endpoint_type=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(
+            package_format='pypi', result=result, include_domain_owner=True,
+            include_duration_seconds=True, include_endpoint_type=True
+        )
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(self._get_pip_commands())
+
     def test_pip_login_with_domain_owner_dry_run(self):
         cmdline = self._setup_cmd(
             tool='pip', include_domain_owner=True, dry_run=True
@@ -736,6 +1104,24 @@ password: {auth_token}'''
             'Argument --namespace is not supported for pip', result.stderr
         )
 
+    def test_pip_login_command_failed_auth_token_redacted(self):
+        def side_effect(command, capture_output, check):
+            raise subprocess.CalledProcessError(
+                returncode=1,
+                cmd=command
+            )
+
+        self.subprocess_mock.side_effect = side_effect
+        cmdline = self._setup_cmd(tool='pip')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 255)
+        self.assertIn(
+            "Command '['pip', 'config', 'set', 'global.index-url',"
+            " 'https://aws:******@domain-domain-owner.codeartifact.aws.a2z.com/pypi/repository/simple/']'"
+            " returned non-zero exit status 1.",
+            result.stderr
+        )
+
     def test_twine_login_without_domain_owner(self):
         cmdline = self._setup_cmd(tool='twine')
         result = self.cli_runner.run(cmdline)
@@ -767,6 +1153,20 @@ password: {auth_token}'''
             password=self.auth_token
         )
 
+    def test_twine_login_without_domain_owner_dry_run_endpoint_type(self):
+        cmdline = self._setup_cmd(tool='twine', dry_run=True, include_endpoint_type=True)
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='pypi', result=result, include_endpoint_type=True)
+        self.assertFalse(os.path.exists(self.test_pypi_rc_path))
+        self._assert_pypi_rc_has_expected_content(
+            pypi_rc_str=self._get_twine_commands(),
+            server='codeartifact',
+            repo_url=self.endpoint,
+            username='aws',
+            password=self.auth_token
+        )
+
     def test_twine_login_with_domain_owner(self):
         cmdline = self._setup_cmd(tool='twine', include_domain_owner=True)
         result = self.cli_runner.run(cmdline)
